==> datami_plugin-0.0.10.tar.gz: ios/Classes/DatamiService.swift <==
//
//  DatamiService.swift
//  datami-flutter
//
//  Created by Fabio Takahashi on 28/11/19.
//  Copyright © 2019 PremierSoft. All rights reserved.
//

import Flutter
import SmiSdk

class DatamiService {

    static var flutterChannel: FlutterMethodChannel?

    static func initSponsoredData(_ sdkKey: String, userId: String, showSDMessage: Bool = true) {
        SmiSdk.initSponsoredData(sdkKey, userId: userId, showSDMessage: showSDMessage)
    }

    /// This method is used for restarting sponsored data after it is stopped.
    ///
    /// When the sponsored data is re-started, the SDK will notify the sdState change to application through SDSTATE_CHANGE_NOTIF notification.
    ///
    /// Calling this API without calling initSponsoredData API will result in no operation.
    static func startSponsorData() {
        SmiSdk.startSponsorData()
    }

    /// This method stops sponsored data for the application.
    ///
    /// When the sponsored data is stopped, the SDK will notify the sdState change to application through SDSTATE_CHANGE_NOTIF notification.
    ///
    /// Calling this method without calling initSponsoredData will result in no operation.
    static func stopSponsoredData() {
        SmiSdk.stopSponsorData()
    }

}

// MARK: - Datami Custom Configuration
extension DatamiService {

    /// Register a custom URLSessionConfiguration (default/ephemeral) with the Datami.
    ///
    /// The method used to add custom URLSession configuration.
    ///
    /// This needs to be called before creating any NSURLSession in the application.
    static func registerAppConfiguration(urlSessionConfiguration: URLSessionConfiguration = .default) {
        SmiSdk.registerAppConfiguration(urlSessionConfiguration)
    }

    static func getSDAuth(sdkKey: String, url: String, userId: String) -> SmiResult {
        return SmiSdk.getSDAuth(sdkKey, url: url, userId: userId)
    }

}

// MARK: - Datami Observers
extension DatamiService {

    static let DATAMI_CHANGE_STATE = NSNotification.Name(rawValue: SDSTATE_CHANGE_NOTIF)

    static func registerNotificationObserver() {
        NotificationCenter.default.addObserver(self, selector:  #selector(receivedStateChange), name: DATAMI_CHANGE_STATE, object: nil)
    }

    @objc static func receivedStateChange(notification: NSNotification) {
        guard let result = notification.object as? SmiResult else {
            return
        }

        #if DEBUG
        print("smiResult sdReason \(result.sdReason.rawValue)")
        print("smiResult sdState \(result.sdState.rawValue)")
        #endif

        guard let flutterChannel = flutterChannel else {
            print("flutterChannel not found")
            return
        }
        flutterChannel.invokeMethod("onSmiStatusChange", arguments: result.sdState.rawValue)
    }

}

==> datami_plugin-0.0.13.tar.gz: ios/Classes/DatamiService.swift <==
//
//  DatamiService.swift
//  datami-flutter
//
//  Created by Fabio Takahashi on 28/11/19.
//  Copyright © 2019 PremierSoft. All rights reserved.
//

import Flutter
import SmiSdk

class DatamiService {

    static var flutterChannel: FlutterMethodChannel?

    static func initSponsoredData(_ sdkKey: String, userId: String, showSDMessage: Bool = true) {
        SmiSdk.initSponsoredData(sdkKey, userId: userId, showSDMessage: showSDMessage)
    }

    /// This method is used for restarting sponsored data after it is stopped.
    ///
    /// When the sponsored data is re-started, the SDK will notify the sdState change to application through SDSTATE_CHANGE_NOTIF notification.
    ///
    /// Calling this API without calling initSponsoredData API will result in no operation.
    static func startSponsorData() {
        SmiSdk.startSponsorData()
    }

    /// This method stops sponsored data for the application.
    ///
    /// When the sponsored data is stopped, the SDK will notify the sdState change to application through SDSTATE_CHANGE_NOTIF notification.
    ///
    /// Calling this method without calling initSponsoredData will result in no operation.
    static func stopSponsoredData() {
        SmiSdk.stopSponsorData()
    }

}

// MARK: - Datami Custom Configuration
extension DatamiService {

    /// Register a custom URLSessionConfiguration (default/ephemeral) with the Datami.
    ///
    /// The method used to add custom URLSession configuration.
    ///
    /// This needs to be called before creating any NSURLSession in the application.
    static func registerAppConfiguration(urlSessionConfiguration: URLSessionConfiguration = .default) {
        SmiSdk.registerAppConfiguration(urlSessionConfiguration)
    }

    static func getSDAuth(sdkKey: String, url: String, userId: String) -> SmiResult {
        return SmiSdk.getSDAuth(sdkKey, url: url, userId: userId)
    }

}

// MARK: - Datami Observers
extension DatamiService {

    static let DATAMI_CHANGE_STATE = NSNotification.Name(rawValue: SDSTATE_CHANGE_NOTIF)

    static func registerNotificationObserver() {
        NotificationCenter.default.addObserver(self, selector:  #selector(receivedStateChange), name: DATAMI_CHANGE_STATE, object: nil)
    }

    @objc static func receivedStateChange(notification: NSNotification) {
        guard let result = notification.object as? SmiResult else {
            return
        }

        debugPrint("-->> smiResult sdReason \(result.sdReason.rawValue)")
        debugPrint("-->> smiResult sdState \(result.sdState.rawValue)")

        guard let flutterChannel = flutterChannel else {
            debugPrint("flutterChannel not found")
            return
        }
        flutterChannel.invokeMethod("onSmiStatusChange", arguments: [result.sdState.rawValue, result.sdReason.rawValue])
    }

}
